@@ -2,6 +2,7 @@ from uuid import UUID
 
 from marshy.factory.dataclass_marshaller_factory import DataclassMarshallerFactory
 from marshy.factory.enum_marshaller_factory import EnumMarshallerFactory
+from marshy.factory.factory_marshaller_factory import FactoryMarshallerFactory
 from marshy.factory.list_marshaller_factory import ListMarshallerFactory
 from marshy.factory.optional_marshaller_factory import OptionalMarshallerFactory
 from marshy.factory.union_marshaller_factory import UnionMarshallerFactory
@@ -24,5 +25,6 @@ def new_default_context() -> MarshallerContext:
     context.register_factory(UnionMarshallerFactory())
     context.register_factory(OptionalMarshallerFactory())
     context.register_factory(ListMarshallerFactory())
+    context.register_factory(FactoryMarshallerFactory())
     context.register_factory(DataclassMarshallerFactory())
     return context
