@@ -4,6 +4,7 @@ from unittest import TestCase
 from marshy import ExternalType
 from marshy.default_context import new_default_context
 from marshy.marshaller.marshaller_abc import MarshallerABC
+from marshy.marshaller_context import MarshallerContext
 
 
 class TestCustomMarshalling(TestCase):
@@ -77,6 +78,11 @@ class Dataset:
             return self.coordinates == other.coordinates
         return NotImplemented
 
+    # noinspection PyUnusedLocal
+    @classmethod
+    def __marshaller_factory__(cls, marshaller_context: MarshallerContext):
+        return DatasetMarshaller()
+
 
 context = new_default_context()
 
@@ -117,4 +123,3 @@ class DatasetMarshaller(MarshallerABC[Dataset]):
 
 
 context.register_marshaller(CoordinateMarshaller())
-context.register_marshaller(DatasetMarshaller())
